@@ -1,6 +1,8 @@
-//#define XERR
+#define XERR
 #include "main.ih"
 
+#include "../tmp/INSTALL.im"
+
 namespace
 {
     Arg::LongOption longOpts[] =
