@@ -17,4 +17,12 @@ void Options::scanIcmconf()
             (this->*(iter->second))();          // process s_icmconf[2] if
                                                 // needed
     }
+
+    if (d_spch != UNSPECIFIED and d_gch != UNSPECIFIED)
+        throw Exception{} << "icm-dep: " << d_icmconf << 
+                             " cannot declare both PRECOMP and SPCH";
+
+    if (d_ih.empty())                           // by default use .ih
+        d_ih = ".ih";
 }
+
