@@ -1,5 +1,3 @@
-//                     version.cc
-
 #include "main.ih"
 #include "icmconf"
 
@@ -12,17 +10,16 @@
 #endif
 
 #ifndef VERSION
-#define VERSION "0.00.00"
+#define VERSION "0.01.00"
 #endif
 
 #ifndef YEARS
-#define YEARS "2011"
+#define YEARS "2020"
 #endif
 
-namespace Icmbuild
+namespace Icmake
 {
     char version[]  = VERSION;
-    char years[]     = YEARS;
-    
-    char author[] = AUTHOR;
+    char years[]    = YEARS;
+    char author[]   = AUTHOR;
 }
